# note to self
A quick and easy note taking tool.

[![asciicast](https://asciinema.org/a/NmKMKV6efl8H2Li62piWKlISo.png)](https://asciinema.org/a/NmKMKV6efl8H2Li62piWKlISo)

# Setup

## Though pip
1. `pip3 install notetoself`

## From source
1. Clone the repo
2. Install pipenv
3. `pipenv install`
4. `pipenv run ./nts.py` to run

# Usage
`nts -h` for help

